@@ -113,7 +113,7 @@ update_os_data (GisPrivacyPage *page)
   if (!privacy_policy)
     privacy_policy = g_strdup ("https://location.services.mozilla.com/privacy");
 
-  text = g_strdup_printf ("<a href='%s'>%s</a>", privacy_policy, _("Privacy Policy"));
+  text = g_strdup_printf ("%s <a href='%s'>%s</a>", _("Uses Mozilla Location Service:"), privacy_policy, _("Privacy Policy"));
   gtk_label_set_markup (GTK_LABEL (priv->privacy_policy_label), text);
   g_free (text);
 
@@ -268,6 +268,12 @@ activate_link (GtkLabel       *label,
   return TRUE;
 }
 
+static void
+gis_privacy_page_locale_changed (GisPage *page)
+{
+  gis_page_set_title (GIS_PAGE (page), _("Privacy"));
+}
+
 static void
 gis_privacy_page_class_init (GisPrivacyPageClass *klass)
 {
@@ -283,6 +289,7 @@ gis_privacy_page_class_init (GisPrivacyPageClass *klass)
   gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), activate_link);
 
   page_class->page_id = PAGE_ID;
+  page_class->locale_changed = gis_privacy_page_locale_changed;
   page_class->apply = gis_privacy_page_apply;
   object_class->constructed = gis_privacy_page_constructed;
   object_class->dispose = gis_privacy_page_dispose;
